@@ -36,8 +36,7 @@ THE SOFTWARE. */
 #include <pugixml/pugixml.hpp>
 
 #include "stdafx.hpp"
-#include "OptionsDialog.hpp"
-#include "AboutDialog.hpp"
+#include "dialogs/AboutDialog.hpp"
 #include "MainWindow.hpp"
 #include "File.hpp"
 #include "FSFile.hpp"
@@ -67,6 +66,7 @@ MainWindow::MainWindow() :
 	this->optionsMenuItem.signal_activate().connect(
 			sigc::mem_fun(*this, &MainWindow::OpenOptionsDialog)
 		);
+	this->optionsMenuItem.set_sensitive(false);
 
 	this->mainMenu.append(*Gtk::manage(new Gtk::SeparatorMenuItem()));
 
@@ -100,6 +100,7 @@ MainWindow::MainWindow() :
 	this->notebook.append_page(this->mainMenuView);
 	this->notebook.append_page(this->thereminView);
 	this->notebook.append_page(this->listenView);
+	this->notebook.append_page(this->keyboardView);
 
 	this->show_all_children();//Show all window child widgets
 }
